# Performance Artifacts Library (primitive-pal)

## Installation

### Project Setup

```bash
# set up a new virtual environment
make setup
```

### Test Locally

```bash
# builds a develop version and sets up an environment in ipython
make shell
```
